==> commandir_utils_0.3.tbz: commandir_utils_0.3/commandir_send.c <==
/*  commandir_send  Version 0.3
    Initial Release: Feb 9, 2011  
    0.2 Release: March 26, 2011
    0.3 Release: June 16, 2011
 */

#include "libcmdir.h"

extern unsigned int tx_bitmask;
extern char * send_filename;

void transmit_tx_char(char * tx_char)
{
  struct sendir * tx = NULL;
  tx = tx_char_2_struct(tx_char);
  if(tx)
  {
    tx->emitterMask = tx_bitmask;
    commandir_sendir(tx);
  }
}


int main(int argc, char **argv)
{
  char * tx_char = NULL, * ptx_char = NULL;
  int x, emitter_num, y;
  unsigned int msDelay = 200;
  struct commandir_device * pcd = NULL;
  struct sendir * tx = NULL;

  if(argc == 1)
  {
    printf("commandir_send v0.3\n");
    printf(" Send IR codes from CommandIR\n\n");
    printf("commandir_send [-dDELAY] [[-bEMITTER_BITMASK_HEX] | [-eEMITTERNUM] -sCOMMANDIR_NAME] FILENAME [FILENAME]...\n");
    printf("commandir_send [-dDELAY] [[-bEMITTER_BITMASK_HEX] | [-eEMITTERNUM] -sCOMMANDIR_NAME] -r [RAW CODE STRING]\n\n");
    printf("Examples:\nSend two commands to emitter 3 with a 500ms delay in between:\n");
    printf(" commandir_send -d500 -e3 amp_volup amp_volup\n");
    printf("Send one command to emitters 1, 2, 3 and 4:\n commandir_send -b0F sa_power\n");
    printf("Send two commands to emitter 2 on a specific CommandIR named 'COMMANDIR_0':\n");
    printf(" commandir_send -sCOMMANDIR_0 -e2 amp_volup amp_volup\n");
//    printf("Send a command to emitters 1, 3, 5, 7, 9 in CommandIR group 'SYSTEM2':\n");
//    printf(" commandir_send -gSYSTEM2 -b155 sa_power\n");
    printf("Send command Hex Code directly:\n");
    printf(" commandir_send -bff -r 0000 0074 0017 0000 0020 0021 0020 0020 0020 0021 0020 0020 0020 0021 0020 0020 0020 0021 0020 0020 0040 0020 0020 0041 003F 0041 0020\n\n");
    printf("-s used in conjunction with commandir_set and CommandIR Firmware 3.42+\n");
    return 0;
  }

  set_all_bitmask(0xff);
  
  for(x=1; x<argc; x++)
  {
    if(argv[x][0] == '-')
    {
      switch(argv[x][1])
      {
        case 's':
          // Named CommandIR - seach for this one
          hardware_scan();
          pcd = getCommandIR_By_Name(&argv[x][2]);
          if(!pcd) {
            printf("CommandIR %s not found!\n", &argv[x][2]);
            return -1;
          }
          break;
        case 'e':
          // Emitter selection
          if(tx_bitmask)
          {
            printf("Cannot specify both -b and -e!\n");
            return -1;
          }
          
          set_all_bitmask(0); // clear bitmask
          emitter_num = atoi(&argv[x][2]);
          if(emitter_num < 1 | emitter_num > 2048)
          {
            printf("Invalid emitter number\n");
            return -1;
          }
          set_long_tx_bit( emitter_num );
          break;
          tx_bitmask = atoi(&argv[x][2]); 
          tx_bitmask = (0x01 << (tx_bitmask-1));
          break;
        case 'b':
          // hex tx_bitmask
          if(tx_bitmask)
          {
            printf("Cannot specify both -e and -b!\n");
            return -1;
          }
          set_all_bitmask(0); // clear bitmask
          convert_set_long(&argv[x][2], strlen(&argv[x][2]));  
          break;
          tx_bitmask = convert_quad(&argv[x][2], strlen(&argv[x][2]));  
          break;
        case 'd':
          msDelay = atoi(&argv[x][2]);
          break;
        case 'r':
          // They're giving us raw codes on the Command Line
          // Use the remaining arguments
          tx_char = malloc(512);  // max 512 bytes
          ptx_char = tx_char;
          for(y=x+1; y<argc; y++) {
            strcpy(ptx_char, argv[y]);
            ptx_char+=strlen(argv[y]);
            *ptx_char++ = ' ';
          }
          break;
      }
    }
  }

  // If it wasn't -s specified, we create a tx map using all possible CommandIRs
  if(!pcd) {
    hardware_scan();
    detect_tx_per_commandir();
  }

  /** Transmit codes **/
  if(tx_char == NULL)
  {
    for(x=1; x<argc; x++)
    {
      if(argv[x][0] != '-')
      {
        send_filename = argv[x];
        tx_char = load_file(argv[x]);
        if(tx_char) // if we have a string from the command line OR a file
        {
          if(pcd) {
            tx = tx_char_2_struct(tx_char);
            commandir_send_specific(tx, pcd);
          } else {  // else regular old LIRC combination mode
            transmit_tx_char(tx_char);
          }
          // Only pause if we have another signal to transmit:
          if(x < argc - 1)
            usleep(msDelay * 1000);
        }
      }
    }
  } else { 
    if(pcd) {
      tx = tx_char_2_struct(tx_char);
      commandir_send_specific(tx, pcd);
    } else {  // else regular old LIRC combination mode
      transmit_tx_char(tx_char);
    }
  }
  
  return 0;
}

==> commandir_utils_0.4.tbz: commandir_utils_0.4/commandir_send.c <==
/*  commandir_send  Version 0.3
    Initial Release: Feb 9, 2011  
    0.2 Release: March 26, 2011
    0.3 Release: June 16, 2011
 */

#include "libcmdir.h"

extern unsigned int tx_bitmask;
extern char * send_filename;

void transmit_tx_char(char * tx_char)
{
  struct sendir * tx = NULL;
  tx = tx_char_2_struct(tx_char);
  if(tx)
  {
    tx->emitterMask = tx_bitmask;
    commandir_sendir(tx);
  }
}


int main(int argc, char **argv)
{
  char * tx_char = NULL, * ptx_char = NULL;
  int x, emitter_num, y;
  unsigned int msDelay = 200;
  struct commandir_device * pcd = NULL;
  struct sendir * tx = NULL;

  if(argc == 1)
  {
    printf("commandir_send v0.4\n");
    printf(" Send IR codes from CommandIR\n\n");
    printf("commandir_send [-dDELAY] [[-bEMITTER_BITMASK_HEX] | [-eEMITTERNUM] -sCOMMANDIR_NAME] FILENAME [FILENAME]...\n");
    printf("commandir_send [-dDELAY] [[-bEMITTER_BITMASK_HEX] | [-eEMITTERNUM] -sCOMMANDIR_NAME] -r [RAW CODE STRING]\n\n");
    printf("Examples:\nSend two commands to emitter 3 with a 500ms delay in between:\n");
    printf(" commandir_send -d500 -e3 amp_volup amp_volup\n");
    printf("Send one command to emitters 1, 2, 3 and 4:\n commandir_send -b0F sa_power\n");
    printf("Send two commands to emitter 2 on a specific CommandIR named 'COMMANDIR_0':\n");
    printf(" commandir_send -sCOMMANDIR_0 -e2 amp_volup amp_volup\n");
//    printf("Send a command to emitters 1, 3, 5, 7, 9 in CommandIR group 'SYSTEM2':\n");
//    printf(" commandir_send -gSYSTEM2 -b155 sa_power\n");
    printf("Send command Hex Code directly:\n");
    printf(" commandir_send -bff -r 0000 0074 0017 0000 0020 0021 0020 0020 0020 0021 0020 0020 0020 0021 0020 0020 0020 0021 0020 0020 0040 0020 0020 0041 003F 0041 0020\n\n");
    printf("-s used in conjunction with commandir_set and CommandIR Firmware 3.42+\n");
    return 0;
  }

  set_all_bitmask(0xff);
  
  for(x=1; x<argc; x++)
  {
    if(argv[x][0] == '-')
    {
      switch(argv[x][1])
      {
        case 's':
          // Named CommandIR - seach for this one
          hardware_scan();
          pcd = getCommandIR_By_Name(&argv[x][2]);
          if(!pcd) {
            printf("CommandIR %s not found!\n", &argv[x][2]);
            return -1;
          }
          break;
        case 'e':
          // Emitter selection
          if(tx_bitmask)
          {
            printf("Cannot specify both -b and -e!\n");
            return -1;
          }
          
          set_all_bitmask(0); // clear bitmask
          emitter_num = atoi(&argv[x][2]);
          if(emitter_num < 1 | emitter_num > 2048)
          {
            printf("Invalid emitter number\n");
            return -1;
          }
          set_long_tx_bit( emitter_num );
          break;
          tx_bitmask = atoi(&argv[x][2]); 
          tx_bitmask = (0x01 << (tx_bitmask-1));
          break;
        case 'b':
          // hex tx_bitmask
          if(tx_bitmask)
          {
            printf("Cannot specify both -e and -b!\n");
            return -1;
          }
          set_all_bitmask(0); // clear bitmask
          convert_set_long(&argv[x][2], strlen(&argv[x][2]));  
          break;
          tx_bitmask = convert_quad(&argv[x][2], strlen(&argv[x][2]));  
          break;
        case 'd':
          msDelay = atoi(&argv[x][2]);
          break;
        case 'r':
          // They're giving us raw codes on the Command Line
          // Use the remaining arguments
          tx_char = malloc(65536); 
          ptx_char = tx_char;
          for(y=x+1; y<argc; y++) {
            strcpy(ptx_char, argv[y]);
            ptx_char+=strlen(argv[y]);
            *ptx_char++ = ' ';
          }
          break;
      }
    }
  }

  // If it wasn't -s specified, we create a tx map using all possible CommandIRs
  if(!pcd) {
    hardware_scan();
    detect_tx_per_commandir();
  }

  /** Transmit codes **/
  if(tx_char == NULL)
  {
    for(x=1; x<argc; x++)
    {
      if(argv[x][0] != '-')
      {
        send_filename = argv[x];
        tx_char = load_file(argv[x]);
        if(tx_char) // if we have a string from the command line OR a file
        {
          if(pcd) {
            tx = tx_char_2_struct(tx_char);
            commandir_send_specific(tx, pcd);
          } else {  // else regular old LIRC combination mode
            transmit_tx_char(tx_char);
          }
          // Only pause if we have another signal to transmit:
          if(x < argc - 1)
            usleep(msDelay * 1000);
        }
      }
    }
  } else { 
    if(pcd) {
      tx = tx_char_2_struct(tx_char);
      commandir_send_specific(tx, pcd);
    } else {  // else regular old LIRC combination mode
      transmit_tx_char(tx_char);
    }
  }
  
  return 0;
}
